summaryrefslogtreecommitdiffstats
path: root/modules/notification/notification.go
diff options
context:
space:
mode:
Diffstat (limited to 'modules/notification/notification.go')
-rw-r--r--modules/notification/notification.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/modules/notification/notification.go b/modules/notification/notification.go
index 95117c1f3e..d120246634 100644
--- a/modules/notification/notification.go
+++ b/modules/notification/notification.go
@@ -150,10 +150,10 @@ func NotifyIssueChangeAssignee(doer *models.User, issue *models.Issue, assignee
}
}
-// NotifyPullRewiewRequest notifies Request Review change
-func NotifyPullRewiewRequest(doer *models.User, issue *models.Issue, reviewer *models.User, isRequest bool, comment *models.Comment) {
+// NotifyPullReviewRequest notifies Request Review change
+func NotifyPullReviewRequest(doer *models.User, issue *models.Issue, reviewer *models.User, isRequest bool, comment *models.Comment) {
for _, notifier := range notifiers {
- notifier.NotifyPullRewiewRequest(doer, issue, reviewer, isRequest, comment)
+ notifier.NotifyPullReviewRequest(doer, issue, reviewer, isRequest, comment)
}
}
-baseline'>automated/noid/stable28-update-psalm-baseline Nextcloud server, a safe home for all your data: https://github.com/nextcloud/serverwww-data
summaryrefslogtreecommitdiffstats
path: root/l10n/lb/lib.po
blob: 8aa81edb8f7865bab131d32be0cd7d69f0083ee5 (plain)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125